@@ -263,6 +263,9 @@ case "$switch" in
      # set locales for clients.
      set_locale_for_clients
 
+     # Now the YP service is up, we can update YP data.
+     make -C /var/yp
+
      #
      echo "Start all DRBL related services by running 'drbl-all-service start'..."
      drbl-all-service start
